@@ -45,9 +45,9 @@ class Comandes:
         return req.json()
 
     def cancelar(self, comanda_id: int):
-        req = self._con.get(url=Comandes._url_cancelar.format(id_com=comanda_id))
+        req = self._con.post(url=Comandes._url_cancelar.format(id_com=comanda_id))
         return req.json()
 
     def tancar(self, comanda_id: int):
-        req = self._con.get(url=Comandes._url_tancar.format(id_com=comanda_id))
+        req = self._con.post(url=Comandes._url_tancar.format(id_com=comanda_id))
         return req.json()
